@@ -1,6 +1,6 @@
 import requests
 from .command_base import CliCommand
-from .utils import error
+from .utils import error, check_response_code
 from tabulate import tabulate
 
 
@@ -26,7 +26,8 @@ class ContainerCommand(CliCommand):
 
         logs_parser = command_subparsers.add_parser('logs', help='Show logs of a running container')
         logs_parser.add_argument('container_name', help='The name of the container to show logs for')
-        logs_parser.add_argument('-f', '--follow', action='store_true', help='Live follow the logs from selected container')
+        logs_parser.add_argument('-f', '--follow', action='store_true',
+                                 help='Live follow the logs from selected container')
 
         start_parser = command_subparsers.add_parser('start', help='Start an container')
         start_parser.add_argument('container_name', help='The name of the container to start')
@@ -71,11 +72,14 @@ class ContainerCommand(CliCommand):
             self._print_containers(self._get_containers())
 
     def remove(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/remove')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/remove',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "removed")
 
     def logs(self, args):
-        data = requests.get(f'{self._apps_api_endpoint}/containers/{args.container_name}/logs')
+        data = check_response_code(requests.get(f'{self._apps_api_endpoint}/containers/{args.container_name}/logs',
+                                                cookies=self._config["cookies"], headers=self._config["extra_headers"]))
         print(data)
         if data:
             print(data.text)
@@ -83,31 +87,44 @@ class ContainerCommand(CliCommand):
             error(f"App {args.container_name} is not installed")
 
     def start(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/start')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/start',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "started")
 
     def stop(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/stop')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/stop',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "stopped")
 
     def restart(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/restart')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/restart',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "restarted")
 
     def enable(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/enable')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/enable',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "enabled")
 
     def disable(self, args):
-        data = requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/disable')
+        data = check_response_code(requests.post(f'{self._apps_api_endpoint}/containers/{args.container_name}/disable',
+                                                 cookies=self._config["cookies"],
+                                                 headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "disabled")
 
     def status(self, args):
-        data = requests.get(f'{self._apps_api_endpoint}/containers/{args.container_name}/status')
+        data = check_response_code(requests.get(f'{self._apps_api_endpoint}/containers/{args.container_name}/status',
+                                                cookies=self._config["cookies"], headers=self._config["extra_headers"]))
         self._print_container_result(data, args.container_name, "status")
 
     def _get_container(self, container):
-        data = requests.get(f'{self._apps_api_endpoint}/containers/{container}')
+        data = check_response_code(
+            requests.get(f'{self._apps_api_endpoint}/containers/{container}', cookies=self._config["cookies"],
+                         headers=self._config["extra_headers"]))
         try:
             body = data.json()
         except:
@@ -121,7 +138,9 @@ class ContainerCommand(CliCommand):
                 error(f"App {container} is not installed")
 
     def _get_containers(self):
-        containers = requests.get(f'{self._apps_api_endpoint}/containers')
+        containers = check_response_code(
+            requests.get(f'{self._apps_api_endpoint}/containers', cookies=self._config["cookies"],
+                         headers=self._config["extra_headers"]))
         if containers:
             return containers.json()
         else:
