@@ -85,11 +85,11 @@ class InfoCommand(CliCommand):
                 print("{}:".format(name))
                 if data['status'] == "running":
                     status_str = "[\033[32mRUNNING\033[39m]"
-                elif data['status'] == "succeed":
-                    status_str = "[\033[32mSUCCEED\033[39m]"
+                elif data['status'] == "succeeded":
+                    status_str = "[\033[32mSUCCEEDED\033[39m]"
                 else:
                     status_str = "[\033[31mERROR\033[39m]"
-                print("\thash: {}".format(data['hash']))
+                print("\tversion: {}".format(data.get('version', data.get('hash', 'no version information'))))
                 print("\tstatus: {}".format(status_str))
         else:
             print("No software information available")
@@ -101,8 +101,8 @@ class InfoCommand(CliCommand):
                 print("{}:".format(software))
                 if data['status'] == "running":
                     status_str = "[\033[32mRUNNING\033[39m]"
-                elif data['status'] == "succeed":
-                    status_str = "[\033[32mSUCCEED\033[39m]"
+                elif data['status'] == "succeeded":
+                    status_str = "[\033[32mSUCCEEDED\033[39m]"
                 else:
                     status_str = "[\033[31mERROR\033[39m]"
                 print("\tstatus: {}".format(status_str))
