@@ -9,6 +9,7 @@ class ReportCommand(CliCommand):
         return 'Download a diagnostic report from your Auterion device'
 
     def __init__(self, config):
+        self._config = config
         self._sysinfo_api_endpoint = f"http://{config['device_address']}/api/sysinfo/v1.0"
 
     def setup_parser(self, parser):
@@ -20,7 +21,8 @@ class ReportCommand(CliCommand):
             report_name += ".zip"
         print("Generating report... This may take a few minutes")
         print(f"Report will be downloaded to {report_name}")
-        download_file(f"{self._sysinfo_api_endpoint}/report", report_name)
+        download_file(f"{self._sysinfo_api_endpoint}/report", report_name, self._config['cookies'],
+                      self._config['extra_headers'])
 
     def handle_exception(self, exception):
         try:
