@@ -3,31 +3,41 @@
 import os
 import argparse
 from auterioncli.commands import available_commands
+import platform
 
 from auterioncli.meta_util import PersistentState, check_for_updates, get_version, eprint, \
     get_device_presence, get_host_device_type
 
 
 def main():
-    persistent = PersistentState()
+    this_device_type = get_host_device_type()
+
+    persistent = PersistentState(this_device_type)
     selected_serial = persistent["selected_serial"]
     selected_address = persistent["selected_address"]
     have_selected_device = selected_serial is not None and selected_address is not None
 
-    host_device = get_host_device_type()
-    env_address = os.getenv('AUTERION_DEVICE_ADDRESS', "127.0.0.1" if host_device == 'skynode' else "10.41.1.1")
+    env_address = os.getenv('AUTERION_DEVICE_ADDRESS', "127.0.0.1" if this_device_type.startswith('auterion') else "10.41.1.1")
 
+    cookies = persistent['cookies'] if 'cookies' in persistent and persistent['cookies'] is not None else {}
+    extra_headers = {'X-CSRF-Token': cookies['csrf_access_token']} if 'csrf_access_token' in cookies else {}
     config = {
+        "version": get_version(),
+        "platform": platform.system() + " " + platform.release(),
         "persistent": persistent,
         "persistent_dir": persistent.persistent_dir,
         "device_address": selected_address if have_selected_device else env_address,
         "device_serial": selected_serial if have_selected_device else None,
-        "have_selected_device": have_selected_device
+        "have_selected_device": have_selected_device,
+        "this_device_type": this_device_type,
+        'cookies': cookies,
+        'extra_headers': extra_headers
     }
     commands = available_commands(config)
 
     main_parser = argparse.ArgumentParser()
     main_parser.add_argument('--version', help='Print version of this tool', action='store_true')
+    main_parser.add_argument('--no-update-check', help='Disable automatic update checks', action='store_true')
     command_subparsers = main_parser.add_subparsers(title="command", metavar='<command>', dest="root_command")
 
     for name, command in commands.items():
@@ -44,7 +54,9 @@ def main():
         main_parser.print_help()
         exit(1)
 
-    check_for_updates(config["persistent"])
+    # Do not check for updates on skynode, or if the user has explicitly disabled it
+    if not args.no_update_check and not config['this_device_type'].startswith('auterion'):
+        check_for_updates(config["persistent"])
 
     # warn user if no device is selected
     if commands[args.root_command].needs_device(args):
@@ -55,9 +67,10 @@ def main():
                    f"Aborting.\n")
             exit(1)
         elif not config['have_selected_device']:
-            eprint(f'Warn: No device serial selected.\n'
-                  f'      Use \'device discover\' and \'device select\' commands to specify which device to use.\n'
-                  f'      Falling back to device with serial {serial_at_address} on {config["device_address"]}\n')
+            if not config['this_device_type'].startswith('auterion'):
+                eprint(f'Warn: No device serial selected.\n'
+                      f'      Use \'device discover\' and \'device select\' commands to specify which device to use.\n'
+                      f'      Falling back to device with serial {serial_at_address} on {config["device_address"]}\n')
 
         elif serial_at_address != config['device_serial']:
             if serial_at_address == '':
