@@ -19,10 +19,14 @@ def get_version():
 
 
 class PersistentState:
-    def __init__(self):
+    def __init__(self, device_type):
         user_home = Path.home()
         self.persistent_dir = user_home / ".auterion-cli"
 
+        # On skynode, we can't store in the users home directory, because it is read-only
+        if device_type.startswith('auterion'):
+            self.persistent_dir = Path('/var/auterion-cli')
+
         # make sure the persistent dir exits
         # Older auterion-cli had .auterion-cli as a file. Remove that file if it exists
         if self.persistent_dir.exists() and self.persistent_dir.is_file():
@@ -61,6 +65,9 @@ class PersistentState:
         if key in self._config:
             del self._config[key]
 
+    def __contains__(self, key):
+        return key in self._config
+
     def persist(self):
         contents = json.dumps(self._config)
         persist_hash = hashlib.sha1(contents.encode()).hexdigest()
@@ -71,13 +78,19 @@ class PersistentState:
             f.write(contents)
 
 
+AUTERION_DEVICES = ['skynode', 'jetson', 'simulation']
+
+
 def get_host_device_type():
     device_type_file = '/persistent/mender/device_type'
     if os.path.exists(device_type_file):
         with open(device_type_file, 'r') as f:
             for l in f.readlines():
                 m = re.match('^device_type=(.*)$', l)
-                return m.group(1)
+                if m:
+                    device = m.group(1).strip().lower()
+                    if device in AUTERION_DEVICES:
+                        return 'auterion-' + device
     return 'unknown'
 
 
@@ -109,7 +122,7 @@ def check_for_updates(persistent_state):
 
     persistent_state['last_update_check_time'] = int(current_time)
 
-    print('Checking for updates...')
+    eprint('Checking for updates...')
     try:
         res = requests.get('https://pypi.org/pypi/auterion-cli/json', timeout=1)
     except requests.exceptions.Timeout:
@@ -125,13 +138,13 @@ def check_for_updates(persistent_state):
         our_version = get_version()
         try:
             if version.parse(up_version) > version.parse(our_version):
-                print("  ┌──────────────────────────────────────────────────────────────────────────────────────┐")
-                print("  │                                                                                      │")
-                print("  │  A new version of auterion-cli is available! {:>20} -> {:<16}│".format(
+                eprint("  ┌──────────────────────────────────────────────────────────────────────────────────────┐")
+                eprint("  │                                                                                      │")
+                eprint("  │  A new version of auterion-cli is available! {:>20} -> {:<16}│".format(
                     our_version, up_version))
-                print("  │                                                                                      │")
-                print("  │  Run `pip install --upgrade auterion-cli` to upgrade.                                │")
-                print("  │                                                                                      │")
-                print("  └──────────────────────────────────────────────────────────────────────────────────────┘")
+                eprint("  │                                                                                      │")
+                eprint("  │  Run `pip install --upgrade auterion-cli` to upgrade.                                │")
+                eprint("  │                                                                                      │")
+                eprint("  └──────────────────────────────────────────────────────────────────────────────────────┘")
         except version.InvalidVersion:
             eprint("Warning: Could not parse version")
